Documentation
¶
Index ¶
- Variables
- func Chmod(name string, mode int) error
- func Chown(path string, uid int, gid int)
- func ClearEnv()
- func Create(name string)
- func Exit(code int)
- func GetEnv(key string) string
- func GetHostname() string
- func GetUserHomeDir() string
- func Getegid() int
- func Geteuid() int
- func Getgid() int
- func Getpid() int
- func Getppid() int
- func Getuid() int
- func Getwd() string
- func Mkdir(name string)
- func ReadDir(name string) []string
- func ReadFile(filename string) string
- func Remove(filename string)
- func RemoveAll(path string)
- func SetEnv(key string, value string)
- func SetEnvByFile(filename string) error
- func UnsetEnv(key string)
- func WriteFile(filename string, content string)
Constants ¶
This section is empty.
Variables ¶
var Variables = map[string]eclaType.Type{}
Functions ¶
func GetUserHomeDir ¶
func GetUserHomeDir() string
GetUserHomeDir gets the home directory of the current user
func SetEnvByFile ¶
SetEnvByFile sets an environment variable by reading a file
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.